==> asksuite-core-1.0.97.tgz: package/keyword_interpreter/keyword-matcher.js <==
const KeywordUtil = require('./keyword-util')
const intents = require('./intents')
let globalKeywordsCache = null;

module.exports = function (config) {

    var apiai = require('./apiai')(config.API_AI_DEVELOPER);

    let KeywordMatcher = {};

    function isDialogFlow(operation) {
        return operation.entityType == "dialogFlow";
    }


    function isSystemOperation(operation) {
        return operation.entityType == "system";
    }


    function isDate(operation) {
        return operation.entity == "date";
    }

    function isNumber(operation) {
        return operation.entity == "number";
    }


    KeywordMatcher.refreshCache = function () {

        return new Promise(async (resolve, reject) => {

            let cacheForSearch = {};

            apiai.getEntities().then(async entities => {

                let map = entities.map(async item => {
                        return await apiai.getKeywordsFromEntity(item);
                });

                let data = await Promise.all(map);

                data.forEach(item => {
                    if (item != null) {
                        cacheForSearch[item.key.name] = item.data;
                    }
                });

                resolve(cacheForSearch)

            })


        }).catch(error => {
            reject(error);
        })

    }


    function evaluate(string, expression, cache) {
        string = string.toLowerCase();
        let isNegative = expression.operation.indexOf("not_") >= 0;
        let value = false;

        if (expression.operation.indexOf("contains") >= 0) {

            if (isDialogFlow(expression)) {

                value = KeywordUtil.hasWordInString(string, cache[expression.entity]);

            } else if (isSystemOperation(expression)) {

                if (isDate(expression)) {
                    value = KeywordUtil.hasDate(string);

                } else if (isNumber(expression)) {
                    value = KeywordUtil.hasNumber(string);
                }

            }
        }

        return isNegative ? !value : value;
    }


    function execute(str, intent, cache) {

        return new Promise((resolve, reject) => {

            let result = intent.expressions.map(item => {
                return evaluate(str, item, cache);
            });

            if (result.indexOf(false) >= 0) {
                resolve({match: false, item: intent});
            } else {
                resolve({match: true, item: intent});
            }
        })
    }

    async function evaluateExpressions(string, expressions, cache) {
        let promises = [];

        expressions.forEach(item => {
            promises.push(execute(string, item, cache));
        });

        let data = await Promise.all(promises);

        return data.filter(item => {
            return item.match;
        })

    }

    KeywordMatcher.getIntent = async function (string, expressions, globalCache) {

       let retruno = await evaluateExpressions(string, expressions, globalCache);

        return retruno;
    }

    KeywordMatcher.matchBase = async function (expressions, globalCache) {

        return new Promise((resolve, reject) => {

            var listResult = [];

            let listClassify = intents.filter(item => {
                return  item.intentResult == "naoentendi" || item.intentResult == "naoentendi_grande"
            });

            listClassify.forEach(async (item, index) => {
                let match = await KeywordMatcher.getIntent(item.textRequest, expressions, globalCache);

                if (match && match.length > 0){
                    listResult.push(item.textRequest)
                }

                if (index == listClassify.length -1){
                    resolve(listResult);
                }

            });

            return listResult;
        })


    };


    return KeywordMatcher;

};

==> asksuite-core-1.0.99.tgz: package/keyword_interpreter/keyword-matcher.js <==
const KeywordUtil = require('./keyword-util')
const intents = require('./intents')
let globalKeywordsCache = null;

module.exports = function (config) {

    var apiai = require('./apiai')(config.API_AI_DEVELOPER);

    let KeywordMatcher = {};

    function isDialogFlow(operation) {
        return operation.entityType == "dialogFlow";
    }


    function isSystemOperation(operation) {
        return operation.entityType == "system";
    }


    function isDate(operation) {
        return operation.entity == "date";
    }

    function isNumber(operation) {
        return operation.entity == "number";
    }


    KeywordMatcher.refreshCache = function () {

        return new Promise(async (resolve, reject) => {

            let cacheForSearch = {};

            apiai.getEntities().then(async entities => {

                let map = entities.map(async item => {
                        return await apiai.getKeywordsFromEntity(item);
                });

                let data = await Promise.all(map);

                data.forEach(item => {
                    if (item != null) {
                        cacheForSearch[item.key.name] = item.data;
                    }
                });

                resolve(cacheForSearch)

            })


        }).catch(error => {
            reject(error);
        })

    }


    function evaluate(string, expression, cache) {
        string = string.toLowerCase();
        let isNegative = expression.operation.indexOf("not_") >= 0;
        let value = false;

        if (expression.operation.indexOf("contains") >= 0) {

            if (isDialogFlow(expression)) {

                value = KeywordUtil.hasWordInString(string, cache[expression.entity]);

                // console.log(string,  cache[expression.entity])
                // console.log(value);

            } else if (isSystemOperation(expression)) {

                if (isDate(expression)) {
                    value = KeywordUtil.hasDate(string);


                } else if (isNumber(expression)) {
                    value = KeywordUtil.hasNumber(string);
                }

            }
        }

        return isNegative ? !value : value;
    }


    function execute(str, intent, cache) {

        return new Promise((resolve, reject) => {

            let result = intent.expressions.map(item => {
                return evaluate(str, item, cache);
            });

            if (result.indexOf(false) >= 0) {
                resolve({match: false, item: intent});
            } else {
                resolve({match: true, item: intent});
            }
        })
    }

    async function evaluateExpressions(string, expressions, cache) {
        let promises = [];

        expressions.forEach(item => {
            promises.push(execute(string, item, cache));
        });

        let data = await Promise.all(promises);

        return data.filter(item => {
            return item.match;
        })

    }

    KeywordMatcher.getIntent = async function (string, expressions, globalCache) {

        let newString = string.replace(/[&#,+()$~%.'":*?<>{}]/g, '');

        console.log("vou testar a string: "+newString)

       let retruno = await evaluateExpressions(newString, expressions, globalCache);

        return retruno;
    }

    KeywordMatcher.matchBase = async function (expressions, globalCache) {

        return new Promise((resolve, reject) => {

            var listResult = [];

            let listClassify = intents.filter(item => {
                return  item.intentResult == "naoentendi" || item.intentResult == "naoentendi_grande"
            });

            listClassify.forEach(async (item, index) => {
                let match = await KeywordMatcher.getIntent(item.textRequest, expressions, globalCache);

                if (match && match.length > 0){
                    listResult.push(item.textRequest)
                }

                if (index == listClassify.length -1){
                    resolve(listResult);
                }

            });

            return listResult;
        })


    };


    return KeywordMatcher;

};
